@@ -32,7 +32,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.44';
+our $VERSION = '2.45';
 
 =head1 SYNOPSIS
 
@@ -759,7 +759,9 @@ sub parse_file_slurm{
             die print "You cannot submit jobs to the queue using nohup! Please remove nohup and try again.\n";
         }
 
-        if( $self->cmd_counter > 0 && 0 == $self->cmd_counter % ($self->commands_per_node + 1) && $self->batch ){
+        $DB::single=2;
+        #if( $self->cmd_counter > 0 && 0 == $self->cmd_counter % ($self->commands_per_node + 1) && $self->batch ){
+        if( $self->cmd_counter > 0 && 0 == $self->cmd_counter % ($self->commands_per_node) && $self->batch ){
             #Run this batch and start the next
             $DB::single=2;
             $self->work;
@@ -789,6 +791,7 @@ sub parse_file_slurm{
             }
             elsif( $self->match_cmd(qr/^wait$/) ){
                 #submit this batch and get the job id so the next can depend upon it
+                $DB::single=2;
                 $self->clear_cmd;
                 $self->wait(1);
                 $self->work if $self->has_batch;
